# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['GitTokenArgs', 'GitToken']

@pulumi.input_type
class GitTokenArgs:
    def __init__(__self__, *,
                 organization_id: pulumi.Input[str],
                 token: pulumi.Input[str],
                 type: pulumi.Input[str],
                 bitbucket_workspace: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a GitToken resource.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] token: Value of the git token.
        :param pulumi.Input[str] type: Type of the git token. - Can be: `BITBUCKET`, `GITHUB`, `GITLAB`.
        :param pulumi.Input[str] bitbucket_workspace: (Mandatory only for Bitbucket git token) Workspace where the token has permissions .
        :param pulumi.Input[str] description: Description of the git token.
        :param pulumi.Input[str] name: Name of the git token.
        """
        pulumi.set(__self__, "organization_id", organization_id)
        pulumi.set(__self__, "token", token)
        pulumi.set(__self__, "type", type)
        if bitbucket_workspace is not None:
            pulumi.set(__self__, "bitbucket_workspace", bitbucket_workspace)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Input[str]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter
    def token(self) -> pulumi.Input[str]:
        """
        Value of the git token.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: pulumi.Input[str]):
        pulumi.set(self, "token", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Type of the git token. - Can be: `BITBUCKET`, `GITHUB`, `GITLAB`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="bitbucketWorkspace")
    def bitbucket_workspace(self) -> Optional[pulumi.Input[str]]:
        """
        (Mandatory only for Bitbucket git token) Workspace where the token has permissions .
        """
        return pulumi.get(self, "bitbucket_workspace")

    @bitbucket_workspace.setter
    def bitbucket_workspace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bitbucket_workspace", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the git token.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the git token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _GitTokenState:
    def __init__(__self__, *,
                 bitbucket_workspace: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering GitToken resources.
        :param pulumi.Input[str] bitbucket_workspace: (Mandatory only for Bitbucket git token) Workspace where the token has permissions .
        :param pulumi.Input[str] description: Description of the git token.
        :param pulumi.Input[str] name: Name of the git token.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] token: Value of the git token.
        :param pulumi.Input[str] type: Type of the git token. - Can be: `BITBUCKET`, `GITHUB`, `GITLAB`.
        """
        if bitbucket_workspace is not None:
            pulumi.set(__self__, "bitbucket_workspace", bitbucket_workspace)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="bitbucketWorkspace")
    def bitbucket_workspace(self) -> Optional[pulumi.Input[str]]:
        """
        (Mandatory only for Bitbucket git token) Workspace where the token has permissions .
        """
        return pulumi.get(self, "bitbucket_workspace")

    @bitbucket_workspace.setter
    def bitbucket_workspace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bitbucket_workspace", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the git token.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the git token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[str]]:
        """
        Value of the git token.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of the git token. - Can be: `BITBUCKET`, `GITHUB`, `GITLAB`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class GitToken(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bitbucket_workspace: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## # GitToken (Resource)

        Provides a Qovery git token resource. This can be used to create and manage Qovery git token.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_git_token = qovery.GitToken("myGitToken",
            organization_id=qovery_organization["my_organization"]["id"],
            type="GITHUB",
            token="my-git-provider-token",
            description="Github token",
            bitbucket_workspace="workspace-bitbucket")
        ```

        ## Import

        ```sh
         $ pulumi import qovery:index/gitToken:GitToken my_git_token "<organization_id>,<git_token_id>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bitbucket_workspace: (Mandatory only for Bitbucket git token) Workspace where the token has permissions .
        :param pulumi.Input[str] description: Description of the git token.
        :param pulumi.Input[str] name: Name of the git token.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] token: Value of the git token.
        :param pulumi.Input[str] type: Type of the git token. - Can be: `BITBUCKET`, `GITHUB`, `GITLAB`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GitTokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # GitToken (Resource)

        Provides a Qovery git token resource. This can be used to create and manage Qovery git token.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_git_token = qovery.GitToken("myGitToken",
            organization_id=qovery_organization["my_organization"]["id"],
            type="GITHUB",
            token="my-git-provider-token",
            description="Github token",
            bitbucket_workspace="workspace-bitbucket")
        ```

        ## Import

        ```sh
         $ pulumi import qovery:index/gitToken:GitToken my_git_token "<organization_id>,<git_token_id>"
        ```

        :param str resource_name: The name of the resource.
        :param GitTokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GitTokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bitbucket_workspace: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GitTokenArgs.__new__(GitTokenArgs)

            __props__.__dict__["bitbucket_workspace"] = bitbucket_workspace
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if organization_id is None and not opts.urn:
                raise TypeError("Missing required property 'organization_id'")
            __props__.__dict__["organization_id"] = organization_id
            if token is None and not opts.urn:
                raise TypeError("Missing required property 'token'")
            __props__.__dict__["token"] = None if token is None else pulumi.Output.secret(token)
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(GitToken, __self__).__init__(
            'qovery:index/gitToken:GitToken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bitbucket_workspace: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            token: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'GitToken':
        """
        Get an existing GitToken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bitbucket_workspace: (Mandatory only for Bitbucket git token) Workspace where the token has permissions .
        :param pulumi.Input[str] description: Description of the git token.
        :param pulumi.Input[str] name: Name of the git token.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] token: Value of the git token.
        :param pulumi.Input[str] type: Type of the git token. - Can be: `BITBUCKET`, `GITHUB`, `GITLAB`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GitTokenState.__new__(_GitTokenState)

        __props__.__dict__["bitbucket_workspace"] = bitbucket_workspace
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["token"] = token
        __props__.__dict__["type"] = type
        return GitToken(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bitbucketWorkspace")
    def bitbucket_workspace(self) -> pulumi.Output[str]:
        """
        (Mandatory only for Bitbucket git token) Workspace where the token has permissions .
        """
        return pulumi.get(self, "bitbucket_workspace")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description of the git token.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the git token.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[str]:
        """
        Value of the git token.
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        Type of the git token. - Can be: `BITBUCKET`, `GITHUB`, `GITLAB`.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetOrganizationResult',
    'AwaitableGetOrganizationResult',
    'get_organization',
    'get_organization_output',
]

@pulumi.output_type
class GetOrganizationResult:
    """
    A collection of values returned by getOrganization.
    """
    def __init__(__self__, description=None, id=None, name=None, plan=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if plan and not isinstance(plan, str):
            raise TypeError("Expected argument 'plan' to be a str")
        pulumi.set(__self__, "plan", plan)

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def plan(self) -> str:
        return pulumi.get(self, "plan")


class AwaitableGetOrganizationResult(GetOrganizationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOrganizationResult(
            description=self.description,
            id=self.id,
            name=self.name,
            plan=self.plan)


def get_organization(id: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOrganizationResult:
    """
    ## # Organization (Data Source)

    Provides a Qovery organization resource. This can be used to create and manage Qovery organizations.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_organization = qovery.get_organization(id="<organization_id>")
    ```
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getOrganization:getOrganization', __args__, opts=opts, typ=GetOrganizationResult).value

    return AwaitableGetOrganizationResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        plan=pulumi.get(__ret__, 'plan'))


@_utilities.lift_output_func(get_organization)
def get_organization_output(id: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetOrganizationResult]:
    """
    ## # Organization (Data Source)

    Provides a Qovery organization resource. This can be used to create and manage Qovery organizations.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_organization = qovery.get_organization(id="<organization_id>")
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['OrganizationArgs', 'Organization']

@pulumi.input_type
class OrganizationArgs:
    def __init__(__self__, *,
                 plan: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Organization resource.
        :param pulumi.Input[str] plan: Plan of the organization. - Can be: `BUSINESS`, `ENTERPRISE`, `ENTERPRISE_YEARLY`, `FREE`, `PROFESSIONAL`, `TEAM`,
               `TEAM_YEARLY`.
        :param pulumi.Input[str] description: Description of the organization.
        :param pulumi.Input[str] name: Name of the organization.
        """
        pulumi.set(__self__, "plan", plan)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Input[str]:
        """
        Plan of the organization. - Can be: `BUSINESS`, `ENTERPRISE`, `ENTERPRISE_YEARLY`, `FREE`, `PROFESSIONAL`, `TEAM`,
        `TEAM_YEARLY`.
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: pulumi.Input[str]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the organization.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the organization.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _OrganizationState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 plan: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Organization resources.
        :param pulumi.Input[str] description: Description of the organization.
        :param pulumi.Input[str] name: Name of the organization.
        :param pulumi.Input[str] plan: Plan of the organization. - Can be: `BUSINESS`, `ENTERPRISE`, `ENTERPRISE_YEARLY`, `FREE`, `PROFESSIONAL`, `TEAM`,
               `TEAM_YEARLY`.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if plan is not None:
            pulumi.set(__self__, "plan", plan)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the organization.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the organization.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def plan(self) -> Optional[pulumi.Input[str]]:
        """
        Plan of the organization. - Can be: `BUSINESS`, `ENTERPRISE`, `ENTERPRISE_YEARLY`, `FREE`, `PROFESSIONAL`, `TEAM`,
        `TEAM_YEARLY`.
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "plan", value)


class Organization(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 plan: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## # Organization (Resource)

        Provides a Qovery organization resource. This can be used to create and manage Qovery organizations.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_organization = qovery.Organization("myOrganization",
            description="My organization description",
            plan="FREE")
        ```

        ## Import

        ```sh
         $ pulumi import qovery:index/organization:Organization my_organization "<organization_id>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the organization.
        :param pulumi.Input[str] name: Name of the organization.
        :param pulumi.Input[str] plan: Plan of the organization. - Can be: `BUSINESS`, `ENTERPRISE`, `ENTERPRISE_YEARLY`, `FREE`, `PROFESSIONAL`, `TEAM`,
               `TEAM_YEARLY`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OrganizationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # Organization (Resource)

        Provides a Qovery organization resource. This can be used to create and manage Qovery organizations.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_organization = qovery.Organization("myOrganization",
            description="My organization description",
            plan="FREE")
        ```

        ## Import

        ```sh
         $ pulumi import qovery:index/organization:Organization my_organization "<organization_id>"
        ```

        :param str resource_name: The name of the resource.
        :param OrganizationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OrganizationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 plan: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OrganizationArgs.__new__(OrganizationArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if plan is None and not opts.urn:
                raise TypeError("Missing required property 'plan'")
            __props__.__dict__["plan"] = plan
        super(Organization, __self__).__init__(
            'qovery:index/organization:Organization',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            plan: Optional[pulumi.Input[str]] = None) -> 'Organization':
        """
        Get an existing Organization resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the organization.
        :param pulumi.Input[str] name: Name of the organization.
        :param pulumi.Input[str] plan: Plan of the organization. - Can be: `BUSINESS`, `ENTERPRISE`, `ENTERPRISE_YEARLY`, `FREE`, `PROFESSIONAL`, `TEAM`,
               `TEAM_YEARLY`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OrganizationState.__new__(_OrganizationState)

        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["plan"] = plan
        return Organization(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description of the organization.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the organization.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Output[str]:
        """
        Plan of the organization. - Can be: `BUSINESS`, `ENTERPRISE`, `ENTERPRISE_YEARLY`, `FREE`, `PROFESSIONAL`, `TEAM`,
        `TEAM_YEARLY`.
        """
        return pulumi.get(self, "plan")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetHelmResult',
    'AwaitableGetHelmResult',
    'get_helm',
    'get_helm_output',
]

@pulumi.output_type
class GetHelmResult:
    """
    A collection of values returned by getHelm.
    """
    def __init__(__self__, advanced_settings_json=None, built_in_environment_variables=None, deployment_restrictions=None, deployment_stage_id=None, environment_id=None, environment_variable_aliases=None, environment_variable_overrides=None, environment_variables=None, external_host=None, id=None, internal_host=None, name=None, secret_aliases=None, secret_overrides=None, secrets=None):
        if advanced_settings_json and not isinstance(advanced_settings_json, str):
            raise TypeError("Expected argument 'advanced_settings_json' to be a str")
        pulumi.set(__self__, "advanced_settings_json", advanced_settings_json)
        if built_in_environment_variables and not isinstance(built_in_environment_variables, list):
            raise TypeError("Expected argument 'built_in_environment_variables' to be a list")
        pulumi.set(__self__, "built_in_environment_variables", built_in_environment_variables)
        if deployment_restrictions and not isinstance(deployment_restrictions, list):
            raise TypeError("Expected argument 'deployment_restrictions' to be a list")
        pulumi.set(__self__, "deployment_restrictions", deployment_restrictions)
        if deployment_stage_id and not isinstance(deployment_stage_id, str):
            raise TypeError("Expected argument 'deployment_stage_id' to be a str")
        pulumi.set(__self__, "deployment_stage_id", deployment_stage_id)
        if environment_id and not isinstance(environment_id, str):
            raise TypeError("Expected argument 'environment_id' to be a str")
        pulumi.set(__self__, "environment_id", environment_id)
        if environment_variable_aliases and not isinstance(environment_variable_aliases, list):
            raise TypeError("Expected argument 'environment_variable_aliases' to be a list")
        pulumi.set(__self__, "environment_variable_aliases", environment_variable_aliases)
        if environment_variable_overrides and not isinstance(environment_variable_overrides, list):
            raise TypeError("Expected argument 'environment_variable_overrides' to be a list")
        pulumi.set(__self__, "environment_variable_overrides", environment_variable_overrides)
        if environment_variables and not isinstance(environment_variables, list):
            raise TypeError("Expected argument 'environment_variables' to be a list")
        pulumi.set(__self__, "environment_variables", environment_variables)
        if external_host and not isinstance(external_host, str):
            raise TypeError("Expected argument 'external_host' to be a str")
        pulumi.set(__self__, "external_host", external_host)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internal_host and not isinstance(internal_host, str):
            raise TypeError("Expected argument 'internal_host' to be a str")
        pulumi.set(__self__, "internal_host", internal_host)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if secret_aliases and not isinstance(secret_aliases, list):
            raise TypeError("Expected argument 'secret_aliases' to be a list")
        pulumi.set(__self__, "secret_aliases", secret_aliases)
        if secret_overrides and not isinstance(secret_overrides, list):
            raise TypeError("Expected argument 'secret_overrides' to be a list")
        pulumi.set(__self__, "secret_overrides", secret_overrides)
        if secrets and not isinstance(secrets, list):
            raise TypeError("Expected argument 'secrets' to be a list")
        pulumi.set(__self__, "secrets", secrets)

    @property
    @pulumi.getter(name="advancedSettingsJson")
    def advanced_settings_json(self) -> str:
        """
        Advanced settings.
        """
        return pulumi.get(self, "advanced_settings_json")

    @property
    @pulumi.getter(name="builtInEnvironmentVariables")
    def built_in_environment_variables(self) -> Sequence['outputs.GetHelmBuiltInEnvironmentVariableResult']:
        """
        List of built-in environment variables linked to this helm.
        """
        return pulumi.get(self, "built_in_environment_variables")

    @property
    @pulumi.getter(name="deploymentRestrictions")
    def deployment_restrictions(self) -> Optional[Sequence['outputs.GetHelmDeploymentRestrictionResult']]:
        """
        List of deployment restrictions
        """
        return pulumi.get(self, "deployment_restrictions")

    @property
    @pulumi.getter(name="deploymentStageId")
    def deployment_stage_id(self) -> str:
        """
        Id of the deployment stage.
        """
        return pulumi.get(self, "deployment_stage_id")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> str:
        """
        Id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> Sequence['outputs.GetHelmEnvironmentVariableAliasResult']:
        """
        List of environment variable aliases linked to this helm.
        """
        return pulumi.get(self, "environment_variable_aliases")

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> Optional[Sequence['outputs.GetHelmEnvironmentVariableOverrideResult']]:
        """
        List of environment variable overrides linked to this helm.
        """
        return pulumi.get(self, "environment_variable_overrides")

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[Sequence['outputs.GetHelmEnvironmentVariableResult']]:
        """
        List of environment variables linked to this helm.
        """
        return pulumi.get(self, "environment_variables")

    @property
    @pulumi.getter(name="externalHost")
    def external_host(self) -> str:
        """
        The helm external FQDN host [NOTE: only if your helm is using a publicly accessible port].
        """
        return pulumi.get(self, "external_host")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Id of the helm.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internalHost")
    def internal_host(self) -> str:
        """
        The helm internal host.
        """
        return pulumi.get(self, "internal_host")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the helm.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> Optional[Sequence['outputs.GetHelmSecretAliasResult']]:
        """
        List of secret aliases linked to this helm.
        """
        return pulumi.get(self, "secret_aliases")

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> Optional[Sequence['outputs.GetHelmSecretOverrideResult']]:
        """
        List of secret overrides linked to this helm.
        """
        return pulumi.get(self, "secret_overrides")

    @property
    @pulumi.getter
    def secrets(self) -> Optional[Sequence['outputs.GetHelmSecretResult']]:
        """
        List of secrets linked to this helm.
        """
        return pulumi.get(self, "secrets")


class AwaitableGetHelmResult(GetHelmResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetHelmResult(
            advanced_settings_json=self.advanced_settings_json,
            built_in_environment_variables=self.built_in_environment_variables,
            deployment_restrictions=self.deployment_restrictions,
            deployment_stage_id=self.deployment_stage_id,
            environment_id=self.environment_id,
            environment_variable_aliases=self.environment_variable_aliases,
            environment_variable_overrides=self.environment_variable_overrides,
            environment_variables=self.environment_variables,
            external_host=self.external_host,
            id=self.id,
            internal_host=self.internal_host,
            name=self.name,
            secret_aliases=self.secret_aliases,
            secret_overrides=self.secret_overrides,
            secrets=self.secrets)


def get_helm(advanced_settings_json: Optional[str] = None,
             deployment_restrictions: Optional[Sequence[pulumi.InputType['GetHelmDeploymentRestrictionArgs']]] = None,
             deployment_stage_id: Optional[str] = None,
             environment_variable_aliases: Optional[Sequence[pulumi.InputType['GetHelmEnvironmentVariableAliasArgs']]] = None,
             environment_variable_overrides: Optional[Sequence[pulumi.InputType['GetHelmEnvironmentVariableOverrideArgs']]] = None,
             environment_variables: Optional[Sequence[pulumi.InputType['GetHelmEnvironmentVariableArgs']]] = None,
             id: Optional[str] = None,
             secret_aliases: Optional[Sequence[pulumi.InputType['GetHelmSecretAliasArgs']]] = None,
             secret_overrides: Optional[Sequence[pulumi.InputType['GetHelmSecretOverrideArgs']]] = None,
             secrets: Optional[Sequence[pulumi.InputType['GetHelmSecretArgs']]] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetHelmResult:
    """
    ## # Helm (Data Source)

    Provides a Qovery helm resource.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_helm = qovery.get_helm(id="<helm_id>")
    ```


    :param str advanced_settings_json: Advanced settings.
    :param Sequence[pulumi.InputType['GetHelmDeploymentRestrictionArgs']] deployment_restrictions: List of deployment restrictions
    :param str deployment_stage_id: Id of the deployment stage.
    :param Sequence[pulumi.InputType['GetHelmEnvironmentVariableAliasArgs']] environment_variable_aliases: List of environment variable aliases linked to this helm.
    :param Sequence[pulumi.InputType['GetHelmEnvironmentVariableOverrideArgs']] environment_variable_overrides: List of environment variable overrides linked to this helm.
    :param Sequence[pulumi.InputType['GetHelmEnvironmentVariableArgs']] environment_variables: List of environment variables linked to this helm.
    :param str id: Id of the environment variable.
    :param Sequence[pulumi.InputType['GetHelmSecretAliasArgs']] secret_aliases: List of secret aliases linked to this helm.
    :param Sequence[pulumi.InputType['GetHelmSecretOverrideArgs']] secret_overrides: List of secret overrides linked to this helm.
    :param Sequence[pulumi.InputType['GetHelmSecretArgs']] secrets: List of secrets linked to this helm.
    """
    __args__ = dict()
    __args__['advancedSettingsJson'] = advanced_settings_json
    __args__['deploymentRestrictions'] = deployment_restrictions
    __args__['deploymentStageId'] = deployment_stage_id
    __args__['environmentVariableAliases'] = environment_variable_aliases
    __args__['environmentVariableOverrides'] = environment_variable_overrides
    __args__['environmentVariables'] = environment_variables
    __args__['id'] = id
    __args__['secretAliases'] = secret_aliases
    __args__['secretOverrides'] = secret_overrides
    __args__['secrets'] = secrets
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getHelm:getHelm', __args__, opts=opts, typ=GetHelmResult).value

    return AwaitableGetHelmResult(
        advanced_settings_json=pulumi.get(__ret__, 'advanced_settings_json'),
        built_in_environment_variables=pulumi.get(__ret__, 'built_in_environment_variables'),
        deployment_restrictions=pulumi.get(__ret__, 'deployment_restrictions'),
        deployment_stage_id=pulumi.get(__ret__, 'deployment_stage_id'),
        environment_id=pulumi.get(__ret__, 'environment_id'),
        environment_variable_aliases=pulumi.get(__ret__, 'environment_variable_aliases'),
        environment_variable_overrides=pulumi.get(__ret__, 'environment_variable_overrides'),
        environment_variables=pulumi.get(__ret__, 'environment_variables'),
        external_host=pulumi.get(__ret__, 'external_host'),
        id=pulumi.get(__ret__, 'id'),
        internal_host=pulumi.get(__ret__, 'internal_host'),
        name=pulumi.get(__ret__, 'name'),
        secret_aliases=pulumi.get(__ret__, 'secret_aliases'),
        secret_overrides=pulumi.get(__ret__, 'secret_overrides'),
        secrets=pulumi.get(__ret__, 'secrets'))


@_utilities.lift_output_func(get_helm)
def get_helm_output(advanced_settings_json: Optional[pulumi.Input[Optional[str]]] = None,
                    deployment_restrictions: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetHelmDeploymentRestrictionArgs']]]]] = None,
                    deployment_stage_id: Optional[pulumi.Input[Optional[str]]] = None,
                    environment_variable_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetHelmEnvironmentVariableAliasArgs']]]]] = None,
                    environment_variable_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetHelmEnvironmentVariableOverrideArgs']]]]] = None,
                    environment_variables: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetHelmEnvironmentVariableArgs']]]]] = None,
                    id: Optional[pulumi.Input[str]] = None,
                    secret_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetHelmSecretAliasArgs']]]]] = None,
                    secret_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetHelmSecretOverrideArgs']]]]] = None,
                    secrets: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetHelmSecretArgs']]]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetHelmResult]:
    """
    ## # Helm (Data Source)

    Provides a Qovery helm resource.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_helm = qovery.get_helm(id="<helm_id>")
    ```


    :param str advanced_settings_json: Advanced settings.
    :param Sequence[pulumi.InputType['GetHelmDeploymentRestrictionArgs']] deployment_restrictions: List of deployment restrictions
    :param str deployment_stage_id: Id of the deployment stage.
    :param Sequence[pulumi.InputType['GetHelmEnvironmentVariableAliasArgs']] environment_variable_aliases: List of environment variable aliases linked to this helm.
    :param Sequence[pulumi.InputType['GetHelmEnvironmentVariableOverrideArgs']] environment_variable_overrides: List of environment variable overrides linked to this helm.
    :param Sequence[pulumi.InputType['GetHelmEnvironmentVariableArgs']] environment_variables: List of environment variables linked to this helm.
    :param str id: Id of the environment variable.
    :param Sequence[pulumi.InputType['GetHelmSecretAliasArgs']] secret_aliases: List of secret aliases linked to this helm.
    :param Sequence[pulumi.InputType['GetHelmSecretOverrideArgs']] secret_overrides: List of secret overrides linked to this helm.
    :param Sequence[pulumi.InputType['GetHelmSecretArgs']] secrets: List of secrets linked to this helm.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('qovery')


class _ExportableConfig(types.ModuleType):
    @property
    def token(self) -> Optional[str]:
        """
        The Qovery API Token to use. This can also be specified with the `QOVERY_API_TOKEN` shell environment variable.
        """
        return __config__.get('token') or _utilities.get_env('QOVERY_API_TOKEN')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['HelmRepositoryArgs', 'HelmRepository']

@pulumi.input_type
class HelmRepositoryArgs:
    def __init__(__self__, *,
                 kind: pulumi.Input[str],
                 organization_id: pulumi.Input[str],
                 skip_tls_verification: pulumi.Input[bool],
                 url: pulumi.Input[str],
                 config: Optional[pulumi.Input['HelmRepositoryConfigArgs']] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a HelmRepository resource.
        :param pulumi.Input[str] kind: Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
               `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[bool] skip_tls_verification: Bypass tls certificate verification when connecting to repository
        :param pulumi.Input[str] url: URL of the helm repository.
        :param pulumi.Input['HelmRepositoryConfigArgs'] config: Configuration needed to authenticate the helm repository.
        :param pulumi.Input[str] description: Description of the helm repository.
        :param pulumi.Input[str] name: Name of the helm repository.
        """
        pulumi.set(__self__, "kind", kind)
        pulumi.set(__self__, "organization_id", organization_id)
        pulumi.set(__self__, "skip_tls_verification", skip_tls_verification)
        pulumi.set(__self__, "url", url)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def kind(self) -> pulumi.Input[str]:
        """
        Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
        `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: pulumi.Input[str]):
        pulumi.set(self, "kind", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Input[str]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="skipTlsVerification")
    def skip_tls_verification(self) -> pulumi.Input[bool]:
        """
        Bypass tls certificate verification when connecting to repository
        """
        return pulumi.get(self, "skip_tls_verification")

    @skip_tls_verification.setter
    def skip_tls_verification(self, value: pulumi.Input[bool]):
        pulumi.set(self, "skip_tls_verification", value)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[str]:
        """
        URL of the helm repository.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[str]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input['HelmRepositoryConfigArgs']]:
        """
        Configuration needed to authenticate the helm repository.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input['HelmRepositoryConfigArgs']]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the helm repository.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the helm repository.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _HelmRepositoryState:
    def __init__(__self__, *,
                 config: Optional[pulumi.Input['HelmRepositoryConfigArgs']] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kind: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 skip_tls_verification: Optional[pulumi.Input[bool]] = None,
                 url: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering HelmRepository resources.
        :param pulumi.Input['HelmRepositoryConfigArgs'] config: Configuration needed to authenticate the helm repository.
        :param pulumi.Input[str] description: Description of the helm repository.
        :param pulumi.Input[str] kind: Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
               `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        :param pulumi.Input[str] name: Name of the helm repository.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[bool] skip_tls_verification: Bypass tls certificate verification when connecting to repository
        :param pulumi.Input[str] url: URL of the helm repository.
        """
        if config is not None:
            pulumi.set(__self__, "config", config)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if skip_tls_verification is not None:
            pulumi.set(__self__, "skip_tls_verification", skip_tls_verification)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input['HelmRepositoryConfigArgs']]:
        """
        Configuration needed to authenticate the helm repository.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input['HelmRepositoryConfigArgs']]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the helm repository.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[str]]:
        """
        Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
        `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kind", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the helm repository.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="skipTlsVerification")
    def skip_tls_verification(self) -> Optional[pulumi.Input[bool]]:
        """
        Bypass tls certificate verification when connecting to repository
        """
        return pulumi.get(self, "skip_tls_verification")

    @skip_tls_verification.setter
    def skip_tls_verification(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "skip_tls_verification", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[str]]:
        """
        URL of the helm repository.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url", value)


class HelmRepository(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[pulumi.InputType['HelmRepositoryConfigArgs']]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kind: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 skip_tls_verification: Optional[pulumi.Input[bool]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## # HelmRepository (Resource)

        Provides a Qovery helm repository resource. This can be used to create and manage Qovery helm repository.

        ## Import

        ```sh
         $ pulumi import qovery:index/helmRepository:HelmRepository my_helm_repository "<organization_id>,<helm_repository_id>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['HelmRepositoryConfigArgs']] config: Configuration needed to authenticate the helm repository.
        :param pulumi.Input[str] description: Description of the helm repository.
        :param pulumi.Input[str] kind: Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
               `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        :param pulumi.Input[str] name: Name of the helm repository.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[bool] skip_tls_verification: Bypass tls certificate verification when connecting to repository
        :param pulumi.Input[str] url: URL of the helm repository.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HelmRepositoryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # HelmRepository (Resource)

        Provides a Qovery helm repository resource. This can be used to create and manage Qovery helm repository.

        ## Import

        ```sh
         $ pulumi import qovery:index/helmRepository:HelmRepository my_helm_repository "<organization_id>,<helm_repository_id>"
        ```

        :param str resource_name: The name of the resource.
        :param HelmRepositoryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HelmRepositoryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[pulumi.InputType['HelmRepositoryConfigArgs']]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kind: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 skip_tls_verification: Optional[pulumi.Input[bool]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HelmRepositoryArgs.__new__(HelmRepositoryArgs)

            __props__.__dict__["config"] = config
            __props__.__dict__["description"] = description
            if kind is None and not opts.urn:
                raise TypeError("Missing required property 'kind'")
            __props__.__dict__["kind"] = kind
            __props__.__dict__["name"] = name
            if organization_id is None and not opts.urn:
                raise TypeError("Missing required property 'organization_id'")
            __props__.__dict__["organization_id"] = organization_id
            if skip_tls_verification is None and not opts.urn:
                raise TypeError("Missing required property 'skip_tls_verification'")
            __props__.__dict__["skip_tls_verification"] = skip_tls_verification
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
        super(HelmRepository, __self__).__init__(
            'qovery:index/helmRepository:HelmRepository',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config: Optional[pulumi.Input[pulumi.InputType['HelmRepositoryConfigArgs']]] = None,
            description: Optional[pulumi.Input[str]] = None,
            kind: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            skip_tls_verification: Optional[pulumi.Input[bool]] = None,
            url: Optional[pulumi.Input[str]] = None) -> 'HelmRepository':
        """
        Get an existing HelmRepository resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['HelmRepositoryConfigArgs']] config: Configuration needed to authenticate the helm repository.
        :param pulumi.Input[str] description: Description of the helm repository.
        :param pulumi.Input[str] kind: Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
               `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        :param pulumi.Input[str] name: Name of the helm repository.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[bool] skip_tls_verification: Bypass tls certificate verification when connecting to repository
        :param pulumi.Input[str] url: URL of the helm repository.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HelmRepositoryState.__new__(_HelmRepositoryState)

        __props__.__dict__["config"] = config
        __props__.__dict__["description"] = description
        __props__.__dict__["kind"] = kind
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["skip_tls_verification"] = skip_tls_verification
        __props__.__dict__["url"] = url
        return HelmRepository(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def config(self) -> pulumi.Output[Optional['outputs.HelmRepositoryConfig']]:
        """
        Configuration needed to authenticate the helm repository.
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description of the helm repository.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def kind(self) -> pulumi.Output[str]:
        """
        Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
        `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        """
        return pulumi.get(self, "kind")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the helm repository.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="skipTlsVerification")
    def skip_tls_verification(self) -> pulumi.Output[bool]:
        """
        Bypass tls certificate verification when connecting to repository
        """
        return pulumi.get(self, "skip_tls_verification")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[str]:
        """
        URL of the helm repository.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetDatabaseResult',
    'AwaitableGetDatabaseResult',
    'get_database',
    'get_database_output',
]

@pulumi.output_type
class GetDatabaseResult:
    """
    A collection of values returned by getDatabase.
    """
    def __init__(__self__, accessibility=None, cpu=None, deployment_stage_id=None, environment_id=None, external_host=None, id=None, instance_type=None, internal_host=None, login=None, memory=None, mode=None, name=None, password=None, port=None, storage=None, type=None, version=None):
        if accessibility and not isinstance(accessibility, str):
            raise TypeError("Expected argument 'accessibility' to be a str")
        pulumi.set(__self__, "accessibility", accessibility)
        if cpu and not isinstance(cpu, int):
            raise TypeError("Expected argument 'cpu' to be a int")
        pulumi.set(__self__, "cpu", cpu)
        if deployment_stage_id and not isinstance(deployment_stage_id, str):
            raise TypeError("Expected argument 'deployment_stage_id' to be a str")
        pulumi.set(__self__, "deployment_stage_id", deployment_stage_id)
        if environment_id and not isinstance(environment_id, str):
            raise TypeError("Expected argument 'environment_id' to be a str")
        pulumi.set(__self__, "environment_id", environment_id)
        if external_host and not isinstance(external_host, str):
            raise TypeError("Expected argument 'external_host' to be a str")
        pulumi.set(__self__, "external_host", external_host)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if internal_host and not isinstance(internal_host, str):
            raise TypeError("Expected argument 'internal_host' to be a str")
        pulumi.set(__self__, "internal_host", internal_host)
        if login and not isinstance(login, str):
            raise TypeError("Expected argument 'login' to be a str")
        pulumi.set(__self__, "login", login)
        if memory and not isinstance(memory, int):
            raise TypeError("Expected argument 'memory' to be a int")
        pulumi.set(__self__, "memory", memory)
        if mode and not isinstance(mode, str):
            raise TypeError("Expected argument 'mode' to be a str")
        pulumi.set(__self__, "mode", mode)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if storage and not isinstance(storage, int):
            raise TypeError("Expected argument 'storage' to be a int")
        pulumi.set(__self__, "storage", storage)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def accessibility(self) -> Optional[str]:
        return pulumi.get(self, "accessibility")

    @property
    @pulumi.getter
    def cpu(self) -> Optional[int]:
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter(name="deploymentStageId")
    def deployment_stage_id(self) -> str:
        return pulumi.get(self, "deployment_stage_id")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> str:
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter(name="externalHost")
    def external_host(self) -> str:
        return pulumi.get(self, "external_host")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> str:
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="internalHost")
    def internal_host(self) -> str:
        return pulumi.get(self, "internal_host")

    @property
    @pulumi.getter
    def login(self) -> str:
        return pulumi.get(self, "login")

    @property
    @pulumi.getter
    def memory(self) -> Optional[int]:
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter
    def mode(self) -> str:
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> str:
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def port(self) -> int:
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def storage(self) -> Optional[int]:
        return pulumi.get(self, "storage")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def version(self) -> str:
        return pulumi.get(self, "version")


class AwaitableGetDatabaseResult(GetDatabaseResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseResult(
            accessibility=self.accessibility,
            cpu=self.cpu,
            deployment_stage_id=self.deployment_stage_id,
            environment_id=self.environment_id,
            external_host=self.external_host,
            id=self.id,
            instance_type=self.instance_type,
            internal_host=self.internal_host,
            login=self.login,
            memory=self.memory,
            mode=self.mode,
            name=self.name,
            password=self.password,
            port=self.port,
            storage=self.storage,
            type=self.type,
            version=self.version)


def get_database(accessibility: Optional[str] = None,
                 cpu: Optional[int] = None,
                 deployment_stage_id: Optional[str] = None,
                 id: Optional[str] = None,
                 instance_type: Optional[str] = None,
                 memory: Optional[int] = None,
                 storage: Optional[int] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseResult:
    """
    ## # Database (Data Source)

    Provides a Qovery database resource. This can be used to create and manage Qovery databases.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_database = qovery.get_database(id="<database_id>")
    ```
    """
    __args__ = dict()
    __args__['accessibility'] = accessibility
    __args__['cpu'] = cpu
    __args__['deploymentStageId'] = deployment_stage_id
    __args__['id'] = id
    __args__['instanceType'] = instance_type
    __args__['memory'] = memory
    __args__['storage'] = storage
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getDatabase:getDatabase', __args__, opts=opts, typ=GetDatabaseResult).value

    return AwaitableGetDatabaseResult(
        accessibility=pulumi.get(__ret__, 'accessibility'),
        cpu=pulumi.get(__ret__, 'cpu'),
        deployment_stage_id=pulumi.get(__ret__, 'deployment_stage_id'),
        environment_id=pulumi.get(__ret__, 'environment_id'),
        external_host=pulumi.get(__ret__, 'external_host'),
        id=pulumi.get(__ret__, 'id'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        internal_host=pulumi.get(__ret__, 'internal_host'),
        login=pulumi.get(__ret__, 'login'),
        memory=pulumi.get(__ret__, 'memory'),
        mode=pulumi.get(__ret__, 'mode'),
        name=pulumi.get(__ret__, 'name'),
        password=pulumi.get(__ret__, 'password'),
        port=pulumi.get(__ret__, 'port'),
        storage=pulumi.get(__ret__, 'storage'),
        type=pulumi.get(__ret__, 'type'),
        version=pulumi.get(__ret__, 'version'))


@_utilities.lift_output_func(get_database)
def get_database_output(accessibility: Optional[pulumi.Input[Optional[str]]] = None,
                        cpu: Optional[pulumi.Input[Optional[int]]] = None,
                        deployment_stage_id: Optional[pulumi.Input[Optional[str]]] = None,
                        id: Optional[pulumi.Input[str]] = None,
                        instance_type: Optional[pulumi.Input[Optional[str]]] = None,
                        memory: Optional[pulumi.Input[Optional[int]]] = None,
                        storage: Optional[pulumi.Input[Optional[int]]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDatabaseResult]:
    """
    ## # Database (Data Source)

    Provides a Qovery database resource. This can be used to create and manage Qovery databases.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_database = qovery.get_database(id="<database_id>")
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetApplicationResult',
    'AwaitableGetApplicationResult',
    'get_application',
    'get_application_output',
]

@pulumi.output_type
class GetApplicationResult:
    """
    A collection of values returned by getApplication.
    """
    def __init__(__self__, advanced_settings_json=None, arguments=None, auto_deploy=None, auto_preview=None, build_mode=None, buildpack_language=None, built_in_environment_variables=None, cpu=None, custom_domains=None, deployment_restrictions=None, deployment_stage_id=None, dockerfile_path=None, entrypoint=None, environment_id=None, environment_variable_aliases=None, environment_variable_overrides=None, environment_variables=None, external_host=None, git_repository=None, healthchecks=None, id=None, internal_host=None, max_running_instances=None, memory=None, min_running_instances=None, name=None, ports=None, secret_aliases=None, secret_overrides=None, secrets=None, storages=None):
        if advanced_settings_json and not isinstance(advanced_settings_json, str):
            raise TypeError("Expected argument 'advanced_settings_json' to be a str")
        pulumi.set(__self__, "advanced_settings_json", advanced_settings_json)
        if arguments and not isinstance(arguments, list):
            raise TypeError("Expected argument 'arguments' to be a list")
        pulumi.set(__self__, "arguments", arguments)
        if auto_deploy and not isinstance(auto_deploy, bool):
            raise TypeError("Expected argument 'auto_deploy' to be a bool")
        pulumi.set(__self__, "auto_deploy", auto_deploy)
        if auto_preview and not isinstance(auto_preview, bool):
            raise TypeError("Expected argument 'auto_preview' to be a bool")
        pulumi.set(__self__, "auto_preview", auto_preview)
        if build_mode and not isinstance(build_mode, str):
            raise TypeError("Expected argument 'build_mode' to be a str")
        pulumi.set(__self__, "build_mode", build_mode)
        if buildpack_language and not isinstance(buildpack_language, str):
            raise TypeError("Expected argument 'buildpack_language' to be a str")
        pulumi.set(__self__, "buildpack_language", buildpack_language)
        if built_in_environment_variables and not isinstance(built_in_environment_variables, list):
            raise TypeError("Expected argument 'built_in_environment_variables' to be a list")
        pulumi.set(__self__, "built_in_environment_variables", built_in_environment_variables)
        if cpu and not isinstance(cpu, int):
            raise TypeError("Expected argument 'cpu' to be a int")
        pulumi.set(__self__, "cpu", cpu)
        if custom_domains and not isinstance(custom_domains, list):
            raise TypeError("Expected argument 'custom_domains' to be a list")
        pulumi.set(__self__, "custom_domains", custom_domains)
        if deployment_restrictions and not isinstance(deployment_restrictions, list):
            raise TypeError("Expected argument 'deployment_restrictions' to be a list")
        pulumi.set(__self__, "deployment_restrictions", deployment_restrictions)
        if deployment_stage_id and not isinstance(deployment_stage_id, str):
            raise TypeError("Expected argument 'deployment_stage_id' to be a str")
        pulumi.set(__self__, "deployment_stage_id", deployment_stage_id)
        if dockerfile_path and not isinstance(dockerfile_path, str):
            raise TypeError("Expected argument 'dockerfile_path' to be a str")
        pulumi.set(__self__, "dockerfile_path", dockerfile_path)
        if entrypoint and not isinstance(entrypoint, str):
            raise TypeError("Expected argument 'entrypoint' to be a str")
        pulumi.set(__self__, "entrypoint", entrypoint)
        if environment_id and not isinstance(environment_id, str):
            raise TypeError("Expected argument 'environment_id' to be a str")
        pulumi.set(__self__, "environment_id", environment_id)
        if environment_variable_aliases and not isinstance(environment_variable_aliases, list):
            raise TypeError("Expected argument 'environment_variable_aliases' to be a list")
        pulumi.set(__self__, "environment_variable_aliases", environment_variable_aliases)
        if environment_variable_overrides and not isinstance(environment_variable_overrides, list):
            raise TypeError("Expected argument 'environment_variable_overrides' to be a list")
        pulumi.set(__self__, "environment_variable_overrides", environment_variable_overrides)
        if environment_variables and not isinstance(environment_variables, list):
            raise TypeError("Expected argument 'environment_variables' to be a list")
        pulumi.set(__self__, "environment_variables", environment_variables)
        if external_host and not isinstance(external_host, str):
            raise TypeError("Expected argument 'external_host' to be a str")
        pulumi.set(__self__, "external_host", external_host)
        if git_repository and not isinstance(git_repository, dict):
            raise TypeError("Expected argument 'git_repository' to be a dict")
        pulumi.set(__self__, "git_repository", git_repository)
        if healthchecks and not isinstance(healthchecks, dict):
            raise TypeError("Expected argument 'healthchecks' to be a dict")
        pulumi.set(__self__, "healthchecks", healthchecks)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internal_host and not isinstance(internal_host, str):
            raise TypeError("Expected argument 'internal_host' to be a str")
        pulumi.set(__self__, "internal_host", internal_host)
        if max_running_instances and not isinstance(max_running_instances, int):
            raise TypeError("Expected argument 'max_running_instances' to be a int")
        pulumi.set(__self__, "max_running_instances", max_running_instances)
        if memory and not isinstance(memory, int):
            raise TypeError("Expected argument 'memory' to be a int")
        pulumi.set(__self__, "memory", memory)
        if min_running_instances and not isinstance(min_running_instances, int):
            raise TypeError("Expected argument 'min_running_instances' to be a int")
        pulumi.set(__self__, "min_running_instances", min_running_instances)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if ports and not isinstance(ports, list):
            raise TypeError("Expected argument 'ports' to be a list")
        pulumi.set(__self__, "ports", ports)
        if secret_aliases and not isinstance(secret_aliases, list):
            raise TypeError("Expected argument 'secret_aliases' to be a list")
        pulumi.set(__self__, "secret_aliases", secret_aliases)
        if secret_overrides and not isinstance(secret_overrides, list):
            raise TypeError("Expected argument 'secret_overrides' to be a list")
        pulumi.set(__self__, "secret_overrides", secret_overrides)
        if secrets and not isinstance(secrets, list):
            raise TypeError("Expected argument 'secrets' to be a list")
        pulumi.set(__self__, "secrets", secrets)
        if storages and not isinstance(storages, list):
            raise TypeError("Expected argument 'storages' to be a list")
        pulumi.set(__self__, "storages", storages)

    @property
    @pulumi.getter(name="advancedSettingsJson")
    def advanced_settings_json(self) -> str:
        return pulumi.get(self, "advanced_settings_json")

    @property
    @pulumi.getter
    def arguments(self) -> Sequence[str]:
        return pulumi.get(self, "arguments")

    @property
    @pulumi.getter(name="autoDeploy")
    def auto_deploy(self) -> bool:
        return pulumi.get(self, "auto_deploy")

    @property
    @pulumi.getter(name="autoPreview")
    def auto_preview(self) -> bool:
        return pulumi.get(self, "auto_preview")

    @property
    @pulumi.getter(name="buildMode")
    def build_mode(self) -> str:
        return pulumi.get(self, "build_mode")

    @property
    @pulumi.getter(name="buildpackLanguage")
    def buildpack_language(self) -> str:
        return pulumi.get(self, "buildpack_language")

    @property
    @pulumi.getter(name="builtInEnvironmentVariables")
    def built_in_environment_variables(self) -> Sequence['outputs.GetApplicationBuiltInEnvironmentVariableResult']:
        return pulumi.get(self, "built_in_environment_variables")

    @property
    @pulumi.getter
    def cpu(self) -> int:
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> Optional[Sequence['outputs.GetApplicationCustomDomainResult']]:
        return pulumi.get(self, "custom_domains")

    @property
    @pulumi.getter(name="deploymentRestrictions")
    def deployment_restrictions(self) -> Optional[Sequence['outputs.GetApplicationDeploymentRestrictionResult']]:
        return pulumi.get(self, "deployment_restrictions")

    @property
    @pulumi.getter(name="deploymentStageId")
    def deployment_stage_id(self) -> str:
        return pulumi.get(self, "deployment_stage_id")

    @property
    @pulumi.getter(name="dockerfilePath")
    def dockerfile_path(self) -> str:
        return pulumi.get(self, "dockerfile_path")

    @property
    @pulumi.getter
    def entrypoint(self) -> str:
        return pulumi.get(self, "entrypoint")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> str:
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> Optional[Sequence['outputs.GetApplicationEnvironmentVariableAliasResult']]:
        return pulumi.get(self, "environment_variable_aliases")

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> Optional[Sequence['outputs.GetApplicationEnvironmentVariableOverrideResult']]:
        return pulumi.get(self, "environment_variable_overrides")

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[Sequence['outputs.GetApplicationEnvironmentVariableResult']]:
        return pulumi.get(self, "environment_variables")

    @property
    @pulumi.getter(name="externalHost")
    def external_host(self) -> str:
        return pulumi.get(self, "external_host")

    @property
    @pulumi.getter(name="gitRepository")
    def git_repository(self) -> 'outputs.GetApplicationGitRepositoryResult':
        return pulumi.get(self, "git_repository")

    @property
    @pulumi.getter
    def healthchecks(self) -> Optional['outputs.GetApplicationHealthchecksResult']:
        return pulumi.get(self, "healthchecks")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internalHost")
    def internal_host(self) -> str:
        return pulumi.get(self, "internal_host")

    @property
    @pulumi.getter(name="maxRunningInstances")
    def max_running_instances(self) -> int:
        return pulumi.get(self, "max_running_instances")

    @property
    @pulumi.getter
    def memory(self) -> int:
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter(name="minRunningInstances")
    def min_running_instances(self) -> int:
        return pulumi.get(self, "min_running_instances")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def ports(self) -> Sequence['outputs.GetApplicationPortResult']:
        return pulumi.get(self, "ports")

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> Optional[Sequence['outputs.GetApplicationSecretAliasResult']]:
        return pulumi.get(self, "secret_aliases")

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> Optional[Sequence['outputs.GetApplicationSecretOverrideResult']]:
        return pulumi.get(self, "secret_overrides")

    @property
    @pulumi.getter
    def secrets(self) -> Optional[Sequence['outputs.GetApplicationSecretResult']]:
        return pulumi.get(self, "secrets")

    @property
    @pulumi.getter
    def storages(self) -> Sequence['outputs.GetApplicationStorageResult']:
        return pulumi.get(self, "storages")


class AwaitableGetApplicationResult(GetApplicationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetApplicationResult(
            advanced_settings_json=self.advanced_settings_json,
            arguments=self.arguments,
            auto_deploy=self.auto_deploy,
            auto_preview=self.auto_preview,
            build_mode=self.build_mode,
            buildpack_language=self.buildpack_language,
            built_in_environment_variables=self.built_in_environment_variables,
            cpu=self.cpu,
            custom_domains=self.custom_domains,
            deployment_restrictions=self.deployment_restrictions,
            deployment_stage_id=self.deployment_stage_id,
            dockerfile_path=self.dockerfile_path,
            entrypoint=self.entrypoint,
            environment_id=self.environment_id,
            environment_variable_aliases=self.environment_variable_aliases,
            environment_variable_overrides=self.environment_variable_overrides,
            environment_variables=self.environment_variables,
            external_host=self.external_host,
            git_repository=self.git_repository,
            healthchecks=self.healthchecks,
            id=self.id,
            internal_host=self.internal_host,
            max_running_instances=self.max_running_instances,
            memory=self.memory,
            min_running_instances=self.min_running_instances,
            name=self.name,
            ports=self.ports,
            secret_aliases=self.secret_aliases,
            secret_overrides=self.secret_overrides,
            secrets=self.secrets,
            storages=self.storages)


def get_application(advanced_settings_json: Optional[str] = None,
                    arguments: Optional[Sequence[str]] = None,
                    auto_deploy: Optional[bool] = None,
                    auto_preview: Optional[bool] = None,
                    buildpack_language: Optional[str] = None,
                    cpu: Optional[int] = None,
                    custom_domains: Optional[Sequence[pulumi.InputType['GetApplicationCustomDomainArgs']]] = None,
                    deployment_restrictions: Optional[Sequence[pulumi.InputType['GetApplicationDeploymentRestrictionArgs']]] = None,
                    deployment_stage_id: Optional[str] = None,
                    dockerfile_path: Optional[str] = None,
                    entrypoint: Optional[str] = None,
                    environment_variable_aliases: Optional[Sequence[pulumi.InputType['GetApplicationEnvironmentVariableAliasArgs']]] = None,
                    environment_variable_overrides: Optional[Sequence[pulumi.InputType['GetApplicationEnvironmentVariableOverrideArgs']]] = None,
                    environment_variables: Optional[Sequence[pulumi.InputType['GetApplicationEnvironmentVariableArgs']]] = None,
                    healthchecks: Optional[pulumi.InputType['GetApplicationHealthchecksArgs']] = None,
                    id: Optional[str] = None,
                    max_running_instances: Optional[int] = None,
                    memory: Optional[int] = None,
                    min_running_instances: Optional[int] = None,
                    secret_aliases: Optional[Sequence[pulumi.InputType['GetApplicationSecretAliasArgs']]] = None,
                    secret_overrides: Optional[Sequence[pulumi.InputType['GetApplicationSecretOverrideArgs']]] = None,
                    secrets: Optional[Sequence[pulumi.InputType['GetApplicationSecretArgs']]] = None,
                    storages: Optional[Sequence[pulumi.InputType['GetApplicationStorageArgs']]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetApplicationResult:
    """
    ## # Application (Data Source)

    Provides a Qovery application resource. This can be used to create and manage Qovery applications.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_application = qovery.get_application(id="<application_id>")
    ```
    """
    __args__ = dict()
    __args__['advancedSettingsJson'] = advanced_settings_json
    __args__['arguments'] = arguments
    __args__['autoDeploy'] = auto_deploy
    __args__['autoPreview'] = auto_preview
    __args__['buildpackLanguage'] = buildpack_language
    __args__['cpu'] = cpu
    __args__['customDomains'] = custom_domains
    __args__['deploymentRestrictions'] = deployment_restrictions
    __args__['deploymentStageId'] = deployment_stage_id
    __args__['dockerfilePath'] = dockerfile_path
    __args__['entrypoint'] = entrypoint
    __args__['environmentVariableAliases'] = environment_variable_aliases
    __args__['environmentVariableOverrides'] = environment_variable_overrides
    __args__['environmentVariables'] = environment_variables
    __args__['healthchecks'] = healthchecks
    __args__['id'] = id
    __args__['maxRunningInstances'] = max_running_instances
    __args__['memory'] = memory
    __args__['minRunningInstances'] = min_running_instances
    __args__['secretAliases'] = secret_aliases
    __args__['secretOverrides'] = secret_overrides
    __args__['secrets'] = secrets
    __args__['storages'] = storages
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getApplication:getApplication', __args__, opts=opts, typ=GetApplicationResult).value

    return AwaitableGetApplicationResult(
        advanced_settings_json=pulumi.get(__ret__, 'advanced_settings_json'),
        arguments=pulumi.get(__ret__, 'arguments'),
        auto_deploy=pulumi.get(__ret__, 'auto_deploy'),
        auto_preview=pulumi.get(__ret__, 'auto_preview'),
        build_mode=pulumi.get(__ret__, 'build_mode'),
        buildpack_language=pulumi.get(__ret__, 'buildpack_language'),
        built_in_environment_variables=pulumi.get(__ret__, 'built_in_environment_variables'),
        cpu=pulumi.get(__ret__, 'cpu'),
        custom_domains=pulumi.get(__ret__, 'custom_domains'),
        deployment_restrictions=pulumi.get(__ret__, 'deployment_restrictions'),
        deployment_stage_id=pulumi.get(__ret__, 'deployment_stage_id'),
        dockerfile_path=pulumi.get(__ret__, 'dockerfile_path'),
        entrypoint=pulumi.get(__ret__, 'entrypoint'),
        environment_id=pulumi.get(__ret__, 'environment_id'),
        environment_variable_aliases=pulumi.get(__ret__, 'environment_variable_aliases'),
        environment_variable_overrides=pulumi.get(__ret__, 'environment_variable_overrides'),
        environment_variables=pulumi.get(__ret__, 'environment_variables'),
        external_host=pulumi.get(__ret__, 'external_host'),
        git_repository=pulumi.get(__ret__, 'git_repository'),
        healthchecks=pulumi.get(__ret__, 'healthchecks'),
        id=pulumi.get(__ret__, 'id'),
        internal_host=pulumi.get(__ret__, 'internal_host'),
        max_running_instances=pulumi.get(__ret__, 'max_running_instances'),
        memory=pulumi.get(__ret__, 'memory'),
        min_running_instances=pulumi.get(__ret__, 'min_running_instances'),
        name=pulumi.get(__ret__, 'name'),
        ports=pulumi.get(__ret__, 'ports'),
        secret_aliases=pulumi.get(__ret__, 'secret_aliases'),
        secret_overrides=pulumi.get(__ret__, 'secret_overrides'),
        secrets=pulumi.get(__ret__, 'secrets'),
        storages=pulumi.get(__ret__, 'storages'))


@_utilities.lift_output_func(get_application)
def get_application_output(advanced_settings_json: Optional[pulumi.Input[Optional[str]]] = None,
                           arguments: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                           auto_deploy: Optional[pulumi.Input[Optional[bool]]] = None,
                           auto_preview: Optional[pulumi.Input[Optional[bool]]] = None,
                           buildpack_language: Optional[pulumi.Input[Optional[str]]] = None,
                           cpu: Optional[pulumi.Input[Optional[int]]] = None,
                           custom_domains: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetApplicationCustomDomainArgs']]]]] = None,
                           deployment_restrictions: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetApplicationDeploymentRestrictionArgs']]]]] = None,
                           deployment_stage_id: Optional[pulumi.Input[Optional[str]]] = None,
                           dockerfile_path: Optional[pulumi.Input[Optional[str]]] = None,
                           entrypoint: Optional[pulumi.Input[Optional[str]]] = None,
                           environment_variable_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetApplicationEnvironmentVariableAliasArgs']]]]] = None,
                           environment_variable_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetApplicationEnvironmentVariableOverrideArgs']]]]] = None,
                           environment_variables: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetApplicationEnvironmentVariableArgs']]]]] = None,
                           healthchecks: Optional[pulumi.Input[Optional[pulumi.InputType['GetApplicationHealthchecksArgs']]]] = None,
                           id: Optional[pulumi.Input[str]] = None,
                           max_running_instances: Optional[pulumi.Input[Optional[int]]] = None,
                           memory: Optional[pulumi.Input[Optional[int]]] = None,
                           min_running_instances: Optional[pulumi.Input[Optional[int]]] = None,
                           secret_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetApplicationSecretAliasArgs']]]]] = None,
                           secret_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetApplicationSecretOverrideArgs']]]]] = None,
                           secrets: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetApplicationSecretArgs']]]]] = None,
                           storages: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetApplicationStorageArgs']]]]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetApplicationResult]:
    """
    ## # Application (Data Source)

    Provides a Qovery application resource. This can be used to create and manage Qovery applications.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_application = qovery.get_application(id="<application_id>")
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EnvironmentArgs', 'Environment']

@pulumi.input_type
class EnvironmentArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[str],
                 project_id: pulumi.Input[str],
                 environment_variable_aliases: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableAliasArgs']]]] = None,
                 environment_variable_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableOverrideArgs']]]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableArgs']]]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 secret_aliases: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretAliasArgs']]]] = None,
                 secret_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretOverrideArgs']]]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretArgs']]]] = None):
        """
        The set of arguments for constructing a Environment resource.
        :param pulumi.Input[str] cluster_id: Id of the cluster [NOTE: can't be updated after creation].
        :param pulumi.Input[str] project_id: Id of the project.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableAliasArgs']]] environment_variable_aliases: List of environment variable aliases linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableOverrideArgs']]] environment_variable_overrides: List of environment variable overrides linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableArgs']]] environment_variables: List of environment variables linked to this environment.
        :param pulumi.Input[str] mode: Mode of the environment. - Can be: `DEVELOPMENT`, `PREVIEW`, `PRODUCTION`, `STAGING`. - Default: `DEVELOPMENT`.
        :param pulumi.Input[str] name: Name of the environment.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretAliasArgs']]] secret_aliases: List of secret aliases linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretOverrideArgs']]] secret_overrides: List of secret overrides linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretArgs']]] secrets: List of secrets linked to this environment.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "project_id", project_id)
        if environment_variable_aliases is not None:
            pulumi.set(__self__, "environment_variable_aliases", environment_variable_aliases)
        if environment_variable_overrides is not None:
            pulumi.set(__self__, "environment_variable_overrides", environment_variable_overrides)
        if environment_variables is not None:
            pulumi.set(__self__, "environment_variables", environment_variables)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secret_aliases is not None:
            pulumi.set(__self__, "secret_aliases", secret_aliases)
        if secret_overrides is not None:
            pulumi.set(__self__, "secret_overrides", secret_overrides)
        if secrets is not None:
            pulumi.set(__self__, "secrets", secrets)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[str]:
        """
        Id of the cluster [NOTE: can't be updated after creation].
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        Id of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableAliasArgs']]]]:
        """
        List of environment variable aliases linked to this environment.
        """
        return pulumi.get(self, "environment_variable_aliases")

    @environment_variable_aliases.setter
    def environment_variable_aliases(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableAliasArgs']]]]):
        pulumi.set(self, "environment_variable_aliases", value)

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableOverrideArgs']]]]:
        """
        List of environment variable overrides linked to this environment.
        """
        return pulumi.get(self, "environment_variable_overrides")

    @environment_variable_overrides.setter
    def environment_variable_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableOverrideArgs']]]]):
        pulumi.set(self, "environment_variable_overrides", value)

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableArgs']]]]:
        """
        List of environment variables linked to this environment.
        """
        return pulumi.get(self, "environment_variables")

    @environment_variables.setter
    def environment_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableArgs']]]]):
        pulumi.set(self, "environment_variables", value)

    @property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[str]]:
        """
        Mode of the environment. - Can be: `DEVELOPMENT`, `PREVIEW`, `PRODUCTION`, `STAGING`. - Default: `DEVELOPMENT`.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mode", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the environment.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretAliasArgs']]]]:
        """
        List of secret aliases linked to this environment.
        """
        return pulumi.get(self, "secret_aliases")

    @secret_aliases.setter
    def secret_aliases(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretAliasArgs']]]]):
        pulumi.set(self, "secret_aliases", value)

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretOverrideArgs']]]]:
        """
        List of secret overrides linked to this environment.
        """
        return pulumi.get(self, "secret_overrides")

    @secret_overrides.setter
    def secret_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretOverrideArgs']]]]):
        pulumi.set(self, "secret_overrides", value)

    @property
    @pulumi.getter
    def secrets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretArgs']]]]:
        """
        List of secrets linked to this environment.
        """
        return pulumi.get(self, "secrets")

    @secrets.setter
    def secrets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretArgs']]]]):
        pulumi.set(self, "secrets", value)


@pulumi.input_type
class _EnvironmentState:
    def __init__(__self__, *,
                 built_in_environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentBuiltInEnvironmentVariableArgs']]]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 environment_variable_aliases: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableAliasArgs']]]] = None,
                 environment_variable_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableOverrideArgs']]]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableArgs']]]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 secret_aliases: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretAliasArgs']]]] = None,
                 secret_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretOverrideArgs']]]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretArgs']]]] = None):
        """
        Input properties used for looking up and filtering Environment resources.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentBuiltInEnvironmentVariableArgs']]] built_in_environment_variables: List of built-in environment variables linked to this environment.
        :param pulumi.Input[str] cluster_id: Id of the cluster [NOTE: can't be updated after creation].
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableAliasArgs']]] environment_variable_aliases: List of environment variable aliases linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableOverrideArgs']]] environment_variable_overrides: List of environment variable overrides linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableArgs']]] environment_variables: List of environment variables linked to this environment.
        :param pulumi.Input[str] mode: Mode of the environment. - Can be: `DEVELOPMENT`, `PREVIEW`, `PRODUCTION`, `STAGING`. - Default: `DEVELOPMENT`.
        :param pulumi.Input[str] name: Name of the environment.
        :param pulumi.Input[str] project_id: Id of the project.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretAliasArgs']]] secret_aliases: List of secret aliases linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretOverrideArgs']]] secret_overrides: List of secret overrides linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretArgs']]] secrets: List of secrets linked to this environment.
        """
        if built_in_environment_variables is not None:
            pulumi.set(__self__, "built_in_environment_variables", built_in_environment_variables)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if environment_variable_aliases is not None:
            pulumi.set(__self__, "environment_variable_aliases", environment_variable_aliases)
        if environment_variable_overrides is not None:
            pulumi.set(__self__, "environment_variable_overrides", environment_variable_overrides)
        if environment_variables is not None:
            pulumi.set(__self__, "environment_variables", environment_variables)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if secret_aliases is not None:
            pulumi.set(__self__, "secret_aliases", secret_aliases)
        if secret_overrides is not None:
            pulumi.set(__self__, "secret_overrides", secret_overrides)
        if secrets is not None:
            pulumi.set(__self__, "secrets", secrets)

    @property
    @pulumi.getter(name="builtInEnvironmentVariables")
    def built_in_environment_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentBuiltInEnvironmentVariableArgs']]]]:
        """
        List of built-in environment variables linked to this environment.
        """
        return pulumi.get(self, "built_in_environment_variables")

    @built_in_environment_variables.setter
    def built_in_environment_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentBuiltInEnvironmentVariableArgs']]]]):
        pulumi.set(self, "built_in_environment_variables", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the cluster [NOTE: can't be updated after creation].
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableAliasArgs']]]]:
        """
        List of environment variable aliases linked to this environment.
        """
        return pulumi.get(self, "environment_variable_aliases")

    @environment_variable_aliases.setter
    def environment_variable_aliases(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableAliasArgs']]]]):
        pulumi.set(self, "environment_variable_aliases", value)

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableOverrideArgs']]]]:
        """
        List of environment variable overrides linked to this environment.
        """
        return pulumi.get(self, "environment_variable_overrides")

    @environment_variable_overrides.setter
    def environment_variable_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableOverrideArgs']]]]):
        pulumi.set(self, "environment_variable_overrides", value)

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableArgs']]]]:
        """
        List of environment variables linked to this environment.
        """
        return pulumi.get(self, "environment_variables")

    @environment_variables.setter
    def environment_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentEnvironmentVariableArgs']]]]):
        pulumi.set(self, "environment_variables", value)

    @property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[str]]:
        """
        Mode of the environment. - Can be: `DEVELOPMENT`, `PREVIEW`, `PRODUCTION`, `STAGING`. - Default: `DEVELOPMENT`.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mode", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the environment.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretAliasArgs']]]]:
        """
        List of secret aliases linked to this environment.
        """
        return pulumi.get(self, "secret_aliases")

    @secret_aliases.setter
    def secret_aliases(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretAliasArgs']]]]):
        pulumi.set(self, "secret_aliases", value)

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretOverrideArgs']]]]:
        """
        List of secret overrides linked to this environment.
        """
        return pulumi.get(self, "secret_overrides")

    @secret_overrides.setter
    def secret_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretOverrideArgs']]]]):
        pulumi.set(self, "secret_overrides", value)

    @property
    @pulumi.getter
    def secrets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretArgs']]]]:
        """
        List of secrets linked to this environment.
        """
        return pulumi.get(self, "secrets")

    @secrets.setter
    def secrets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentSecretArgs']]]]):
        pulumi.set(self, "secrets", value)


class Environment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 environment_variable_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableAliasArgs']]]]] = None,
                 environment_variable_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableOverrideArgs']]]]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableArgs']]]]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 secret_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretAliasArgs']]]]] = None,
                 secret_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretOverrideArgs']]]]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretArgs']]]]] = None,
                 __props__=None):
        """
        ## # Environment (Resource)

        Provides a Qovery environment resource. This can be used to create and manage Qovery environments.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_environment = qovery.Environment("myEnvironment",
            project_id=qovery_project["my_project"]["id"],
            cluster_id=qovery_cluster["my_cluster"]["id"],
            mode="DEVELOPMENT",
            environment_variables=[qovery.EnvironmentEnvironmentVariableArgs(
                key="ENV_VAR_KEY",
                value="ENV_VAR_VALUE",
            )],
            environment_variable_aliases=[qovery.EnvironmentEnvironmentVariableAliasArgs(
                key="ENV_VAR_KEY_ALIAS",
                value="ENV_VAR_KEY",
            )],
            environment_variable_overrides=[qovery.EnvironmentEnvironmentVariableOverrideArgs(
                key="SOME_PROJECT_VARIABLE",
                value="OVERRIDDEN_VALUE",
            )],
            secrets=[qovery.EnvironmentSecretArgs(
                key="SECRET_KEY",
                value="SECRET_VALUE",
            )],
            secret_aliases=[qovery.EnvironmentSecretAliasArgs(
                key="SECRET_KEY_ALIAS",
                value="SECRET_KEY",
            )],
            secret_overrides=[qovery.EnvironmentSecretOverrideArgs(
                key="SOME_PROJECT_SECRET",
                value="OVERRIDDEN_VALUE",
            )],
            opts=pulumi.ResourceOptions(depends_on=[qovery_project["my_project"]]))
        ```

        You can find complete examples within these repositories:

        * Deploy an Application and Database within 3 environments

        ## Import

        ```sh
         $ pulumi import qovery:index/environment:Environment my_environment "<environment_id>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_id: Id of the cluster [NOTE: can't be updated after creation].
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableAliasArgs']]]] environment_variable_aliases: List of environment variable aliases linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableOverrideArgs']]]] environment_variable_overrides: List of environment variable overrides linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableArgs']]]] environment_variables: List of environment variables linked to this environment.
        :param pulumi.Input[str] mode: Mode of the environment. - Can be: `DEVELOPMENT`, `PREVIEW`, `PRODUCTION`, `STAGING`. - Default: `DEVELOPMENT`.
        :param pulumi.Input[str] name: Name of the environment.
        :param pulumi.Input[str] project_id: Id of the project.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretAliasArgs']]]] secret_aliases: List of secret aliases linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretOverrideArgs']]]] secret_overrides: List of secret overrides linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretArgs']]]] secrets: List of secrets linked to this environment.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EnvironmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # Environment (Resource)

        Provides a Qovery environment resource. This can be used to create and manage Qovery environments.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_environment = qovery.Environment("myEnvironment",
            project_id=qovery_project["my_project"]["id"],
            cluster_id=qovery_cluster["my_cluster"]["id"],
            mode="DEVELOPMENT",
            environment_variables=[qovery.EnvironmentEnvironmentVariableArgs(
                key="ENV_VAR_KEY",
                value="ENV_VAR_VALUE",
            )],
            environment_variable_aliases=[qovery.EnvironmentEnvironmentVariableAliasArgs(
                key="ENV_VAR_KEY_ALIAS",
                value="ENV_VAR_KEY",
            )],
            environment_variable_overrides=[qovery.EnvironmentEnvironmentVariableOverrideArgs(
                key="SOME_PROJECT_VARIABLE",
                value="OVERRIDDEN_VALUE",
            )],
            secrets=[qovery.EnvironmentSecretArgs(
                key="SECRET_KEY",
                value="SECRET_VALUE",
            )],
            secret_aliases=[qovery.EnvironmentSecretAliasArgs(
                key="SECRET_KEY_ALIAS",
                value="SECRET_KEY",
            )],
            secret_overrides=[qovery.EnvironmentSecretOverrideArgs(
                key="SOME_PROJECT_SECRET",
                value="OVERRIDDEN_VALUE",
            )],
            opts=pulumi.ResourceOptions(depends_on=[qovery_project["my_project"]]))
        ```

        You can find complete examples within these repositories:

        * Deploy an Application and Database within 3 environments

        ## Import

        ```sh
         $ pulumi import qovery:index/environment:Environment my_environment "<environment_id>"
        ```

        :param str resource_name: The name of the resource.
        :param EnvironmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EnvironmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 environment_variable_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableAliasArgs']]]]] = None,
                 environment_variable_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableOverrideArgs']]]]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableArgs']]]]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 secret_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretAliasArgs']]]]] = None,
                 secret_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretOverrideArgs']]]]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EnvironmentArgs.__new__(EnvironmentArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["environment_variable_aliases"] = environment_variable_aliases
            __props__.__dict__["environment_variable_overrides"] = environment_variable_overrides
            __props__.__dict__["environment_variables"] = environment_variables
            __props__.__dict__["mode"] = mode
            __props__.__dict__["name"] = name
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["secret_aliases"] = secret_aliases
            __props__.__dict__["secret_overrides"] = secret_overrides
            __props__.__dict__["secrets"] = secrets
            __props__.__dict__["built_in_environment_variables"] = None
        super(Environment, __self__).__init__(
            'qovery:index/environment:Environment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            built_in_environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentBuiltInEnvironmentVariableArgs']]]]] = None,
            cluster_id: Optional[pulumi.Input[str]] = None,
            environment_variable_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableAliasArgs']]]]] = None,
            environment_variable_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableOverrideArgs']]]]] = None,
            environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableArgs']]]]] = None,
            mode: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            secret_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretAliasArgs']]]]] = None,
            secret_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretOverrideArgs']]]]] = None,
            secrets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretArgs']]]]] = None) -> 'Environment':
        """
        Get an existing Environment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentBuiltInEnvironmentVariableArgs']]]] built_in_environment_variables: List of built-in environment variables linked to this environment.
        :param pulumi.Input[str] cluster_id: Id of the cluster [NOTE: can't be updated after creation].
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableAliasArgs']]]] environment_variable_aliases: List of environment variable aliases linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableOverrideArgs']]]] environment_variable_overrides: List of environment variable overrides linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentEnvironmentVariableArgs']]]] environment_variables: List of environment variables linked to this environment.
        :param pulumi.Input[str] mode: Mode of the environment. - Can be: `DEVELOPMENT`, `PREVIEW`, `PRODUCTION`, `STAGING`. - Default: `DEVELOPMENT`.
        :param pulumi.Input[str] name: Name of the environment.
        :param pulumi.Input[str] project_id: Id of the project.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretAliasArgs']]]] secret_aliases: List of secret aliases linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretOverrideArgs']]]] secret_overrides: List of secret overrides linked to this environment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['EnvironmentSecretArgs']]]] secrets: List of secrets linked to this environment.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EnvironmentState.__new__(_EnvironmentState)

        __props__.__dict__["built_in_environment_variables"] = built_in_environment_variables
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["environment_variable_aliases"] = environment_variable_aliases
        __props__.__dict__["environment_variable_overrides"] = environment_variable_overrides
        __props__.__dict__["environment_variables"] = environment_variables
        __props__.__dict__["mode"] = mode
        __props__.__dict__["name"] = name
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["secret_aliases"] = secret_aliases
        __props__.__dict__["secret_overrides"] = secret_overrides
        __props__.__dict__["secrets"] = secrets
        return Environment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="builtInEnvironmentVariables")
    def built_in_environment_variables(self) -> pulumi.Output[Sequence['outputs.EnvironmentBuiltInEnvironmentVariable']]:
        """
        List of built-in environment variables linked to this environment.
        """
        return pulumi.get(self, "built_in_environment_variables")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[str]:
        """
        Id of the cluster [NOTE: can't be updated after creation].
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> pulumi.Output[Optional[Sequence['outputs.EnvironmentEnvironmentVariableAlias']]]:
        """
        List of environment variable aliases linked to this environment.
        """
        return pulumi.get(self, "environment_variable_aliases")

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> pulumi.Output[Optional[Sequence['outputs.EnvironmentEnvironmentVariableOverride']]]:
        """
        List of environment variable overrides linked to this environment.
        """
        return pulumi.get(self, "environment_variable_overrides")

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> pulumi.Output[Optional[Sequence['outputs.EnvironmentEnvironmentVariable']]]:
        """
        List of environment variables linked to this environment.
        """
        return pulumi.get(self, "environment_variables")

    @property
    @pulumi.getter
    def mode(self) -> pulumi.Output[str]:
        """
        Mode of the environment. - Can be: `DEVELOPMENT`, `PREVIEW`, `PRODUCTION`, `STAGING`. - Default: `DEVELOPMENT`.
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the environment.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        Id of the project.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> pulumi.Output[Optional[Sequence['outputs.EnvironmentSecretAlias']]]:
        """
        List of secret aliases linked to this environment.
        """
        return pulumi.get(self, "secret_aliases")

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> pulumi.Output[Optional[Sequence['outputs.EnvironmentSecretOverride']]]:
        """
        List of secret overrides linked to this environment.
        """
        return pulumi.get(self, "secret_overrides")

    @property
    @pulumi.getter
    def secrets(self) -> pulumi.Output[Optional[Sequence['outputs.EnvironmentSecret']]]:
        """
        List of secrets linked to this environment.
        """
        return pulumi.get(self, "secrets")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetEnvironmentResult',
    'AwaitableGetEnvironmentResult',
    'get_environment',
    'get_environment_output',
]

@pulumi.output_type
class GetEnvironmentResult:
    """
    A collection of values returned by getEnvironment.
    """
    def __init__(__self__, built_in_environment_variables=None, cluster_id=None, environment_variable_aliases=None, environment_variable_overrides=None, environment_variables=None, id=None, mode=None, name=None, project_id=None, secret_aliases=None, secret_overrides=None, secrets=None):
        if built_in_environment_variables and not isinstance(built_in_environment_variables, list):
            raise TypeError("Expected argument 'built_in_environment_variables' to be a list")
        pulumi.set(__self__, "built_in_environment_variables", built_in_environment_variables)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if environment_variable_aliases and not isinstance(environment_variable_aliases, list):
            raise TypeError("Expected argument 'environment_variable_aliases' to be a list")
        pulumi.set(__self__, "environment_variable_aliases", environment_variable_aliases)
        if environment_variable_overrides and not isinstance(environment_variable_overrides, list):
            raise TypeError("Expected argument 'environment_variable_overrides' to be a list")
        pulumi.set(__self__, "environment_variable_overrides", environment_variable_overrides)
        if environment_variables and not isinstance(environment_variables, list):
            raise TypeError("Expected argument 'environment_variables' to be a list")
        pulumi.set(__self__, "environment_variables", environment_variables)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if mode and not isinstance(mode, str):
            raise TypeError("Expected argument 'mode' to be a str")
        pulumi.set(__self__, "mode", mode)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if secret_aliases and not isinstance(secret_aliases, list):
            raise TypeError("Expected argument 'secret_aliases' to be a list")
        pulumi.set(__self__, "secret_aliases", secret_aliases)
        if secret_overrides and not isinstance(secret_overrides, list):
            raise TypeError("Expected argument 'secret_overrides' to be a list")
        pulumi.set(__self__, "secret_overrides", secret_overrides)
        if secrets and not isinstance(secrets, list):
            raise TypeError("Expected argument 'secrets' to be a list")
        pulumi.set(__self__, "secrets", secrets)

    @property
    @pulumi.getter(name="builtInEnvironmentVariables")
    def built_in_environment_variables(self) -> Sequence['outputs.GetEnvironmentBuiltInEnvironmentVariableResult']:
        return pulumi.get(self, "built_in_environment_variables")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> Sequence['outputs.GetEnvironmentEnvironmentVariableAliasResult']:
        return pulumi.get(self, "environment_variable_aliases")

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> Sequence['outputs.GetEnvironmentEnvironmentVariableOverrideResult']:
        return pulumi.get(self, "environment_variable_overrides")

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Sequence['outputs.GetEnvironmentEnvironmentVariableResult']:
        return pulumi.get(self, "environment_variables")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def mode(self) -> str:
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> Sequence['outputs.GetEnvironmentSecretAliasResult']:
        return pulumi.get(self, "secret_aliases")

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> Optional[Sequence['outputs.GetEnvironmentSecretOverrideResult']]:
        return pulumi.get(self, "secret_overrides")

    @property
    @pulumi.getter
    def secrets(self) -> Sequence['outputs.GetEnvironmentSecretResult']:
        return pulumi.get(self, "secrets")


class AwaitableGetEnvironmentResult(GetEnvironmentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnvironmentResult(
            built_in_environment_variables=self.built_in_environment_variables,
            cluster_id=self.cluster_id,
            environment_variable_aliases=self.environment_variable_aliases,
            environment_variable_overrides=self.environment_variable_overrides,
            environment_variables=self.environment_variables,
            id=self.id,
            mode=self.mode,
            name=self.name,
            project_id=self.project_id,
            secret_aliases=self.secret_aliases,
            secret_overrides=self.secret_overrides,
            secrets=self.secrets)


def get_environment(environment_variable_aliases: Optional[Sequence[pulumi.InputType['GetEnvironmentEnvironmentVariableAliasArgs']]] = None,
                    environment_variable_overrides: Optional[Sequence[pulumi.InputType['GetEnvironmentEnvironmentVariableOverrideArgs']]] = None,
                    environment_variables: Optional[Sequence[pulumi.InputType['GetEnvironmentEnvironmentVariableArgs']]] = None,
                    id: Optional[str] = None,
                    mode: Optional[str] = None,
                    secret_aliases: Optional[Sequence[pulumi.InputType['GetEnvironmentSecretAliasArgs']]] = None,
                    secret_overrides: Optional[Sequence[pulumi.InputType['GetEnvironmentSecretOverrideArgs']]] = None,
                    secrets: Optional[Sequence[pulumi.InputType['GetEnvironmentSecretArgs']]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnvironmentResult:
    """
    ## # Environment (Data Source)

    Provides a Qovery environment resource. This can be used to create and manage Qovery environments.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_environment = qovery.get_environment(id="<environment_id>")
    ```
    """
    __args__ = dict()
    __args__['environmentVariableAliases'] = environment_variable_aliases
    __args__['environmentVariableOverrides'] = environment_variable_overrides
    __args__['environmentVariables'] = environment_variables
    __args__['id'] = id
    __args__['mode'] = mode
    __args__['secretAliases'] = secret_aliases
    __args__['secretOverrides'] = secret_overrides
    __args__['secrets'] = secrets
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getEnvironment:getEnvironment', __args__, opts=opts, typ=GetEnvironmentResult).value

    return AwaitableGetEnvironmentResult(
        built_in_environment_variables=pulumi.get(__ret__, 'built_in_environment_variables'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        environment_variable_aliases=pulumi.get(__ret__, 'environment_variable_aliases'),
        environment_variable_overrides=pulumi.get(__ret__, 'environment_variable_overrides'),
        environment_variables=pulumi.get(__ret__, 'environment_variables'),
        id=pulumi.get(__ret__, 'id'),
        mode=pulumi.get(__ret__, 'mode'),
        name=pulumi.get(__ret__, 'name'),
        project_id=pulumi.get(__ret__, 'project_id'),
        secret_aliases=pulumi.get(__ret__, 'secret_aliases'),
        secret_overrides=pulumi.get(__ret__, 'secret_overrides'),
        secrets=pulumi.get(__ret__, 'secrets'))


@_utilities.lift_output_func(get_environment)
def get_environment_output(environment_variable_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetEnvironmentEnvironmentVariableAliasArgs']]]]] = None,
                           environment_variable_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetEnvironmentEnvironmentVariableOverrideArgs']]]]] = None,
                           environment_variables: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetEnvironmentEnvironmentVariableArgs']]]]] = None,
                           id: Optional[pulumi.Input[str]] = None,
                           mode: Optional[pulumi.Input[Optional[str]]] = None,
                           secret_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetEnvironmentSecretAliasArgs']]]]] = None,
                           secret_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetEnvironmentSecretOverrideArgs']]]]] = None,
                           secrets: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetEnvironmentSecretArgs']]]]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnvironmentResult]:
    """
    ## # Environment (Data Source)

    Provides a Qovery environment resource. This can be used to create and manage Qovery environments.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_environment = qovery.get_environment(id="<environment_id>")
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetGitTokenResult',
    'AwaitableGetGitTokenResult',
    'get_git_token',
    'get_git_token_output',
]

@pulumi.output_type
class GetGitTokenResult:
    """
    A collection of values returned by getGitToken.
    """
    def __init__(__self__, bitbucket_workspace=None, description=None, id=None, name=None, organization_id=None, token=None, type=None):
        if bitbucket_workspace and not isinstance(bitbucket_workspace, str):
            raise TypeError("Expected argument 'bitbucket_workspace' to be a str")
        pulumi.set(__self__, "bitbucket_workspace", bitbucket_workspace)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if token and not isinstance(token, str):
            raise TypeError("Expected argument 'token' to be a str")
        pulumi.set(__self__, "token", token)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="bitbucketWorkspace")
    def bitbucket_workspace(self) -> str:
        return pulumi.get(self, "bitbucket_workspace")

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def token(self) -> str:
        return pulumi.get(self, "token")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")


class AwaitableGetGitTokenResult(GetGitTokenResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGitTokenResult(
            bitbucket_workspace=self.bitbucket_workspace,
            description=self.description,
            id=self.id,
            name=self.name,
            organization_id=self.organization_id,
            token=self.token,
            type=self.type)


def get_git_token(bitbucket_workspace: Optional[str] = None,
                  description: Optional[str] = None,
                  id: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGitTokenResult:
    """
    ## # GitToken (Data Source)

    Provides a Qovery git token resource. This can be used to create and manage Qovery git token.
    """
    __args__ = dict()
    __args__['bitbucketWorkspace'] = bitbucket_workspace
    __args__['description'] = description
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getGitToken:getGitToken', __args__, opts=opts, typ=GetGitTokenResult).value

    return AwaitableGetGitTokenResult(
        bitbucket_workspace=pulumi.get(__ret__, 'bitbucket_workspace'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        token=pulumi.get(__ret__, 'token'),
        type=pulumi.get(__ret__, 'type'))


@_utilities.lift_output_func(get_git_token)
def get_git_token_output(bitbucket_workspace: Optional[pulumi.Input[Optional[str]]] = None,
                         description: Optional[pulumi.Input[Optional[str]]] = None,
                         id: Optional[pulumi.Input[str]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetGitTokenResult]:
    """
    ## # GitToken (Data Source)

    Provides a Qovery git token resource. This can be used to create and manage Qovery git token.
    """
    ...
